==> amazonMap-0.01.zip: amazonMap/include/PostConfirm.php <==
<?php
/**
@version $Id$
*/

require_once "exComponent/render/ConfirmModelRender.php";
require_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";

class AmazonmapComponentModelRender extends exConfirmComponentModelRender {
	function render() {
		$editform=Session::get($this->component_->name_);

		$handler=&AmazonSoapHandler::getInstance();
		$amazon=&$handler->get($editform->asin_);
		
		$form=new XoopsThemeForm("AmazonMap","AmazonMap",$_SERVER['SCRIPT_NAME'],"POST");
		
		$ticket=$this->component_->form_->getStructure();
		$form->addElement(new XoopsFormHidden($ticket['__ticket__']['name'],$ticket['__ticket__']['value']));

		foreach($amazon as $key=>$value) {
			// üɽ
			if($key=='Url') {
				$value=@sprintf("<a href='%s' target='_blank'>Amazon Url</a>",$value);
			}
			elseif(strpos($key,"ImageUrl")===0) {
				$value=@sprintf("<img src='%s' alt='%s' />",$value,$value);
			}

			$form->addElement(new XoopsFormLabel($key,nl2br($value)));
		}

       	$formtray = new XoopsFormElementTray("ACTION");
       	$formtray->addElement( new XoopsFormButton ( "", "save", "Confirm", "submit" ) );
       	$backButton = new XoopsFormButton ( "", "back", "Back", "button" );
       	$backButton->setExtra('onclick="javascript:history.go(-1);"');
       	$formtray->addElement($backButton);
        	
       	$form->addElement($formtray);

		$form->display();

	}
}

class AmazonmapInputProcessor extends exTypicalConfirmComponentProcessor
{
	function _processPost($component) {
		global $xoopsDB;

		$editform=Session::pop($component->name_);

		$sql=@sprintf("INSERT INTO %s (path,param1,param2,asin) VALUES ( %s,%u,%u,%s)",
			$xoopsDB->prefix("amazonmap_mapping"),
			$xoopsDB->quoteString($editform->path_),
			$editform->param1_,
			$editform->param2_,
			$xoopsDB->quoteString($editform->asin_));
			
		return $xoopsDB->query($sql);
	}
}

?>

==> amazonMap-0.06.zip: amazonMap/include/PostConfirm.php <==
<?php
/**
@version $Id$
*/

require_once "exComponent/render/ConfirmModelRender.php";
require_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";

class AmazonmapComponentModelRender extends exConfirmComponentModelRender {
	function render() {
		$editform=Session::get($this->component_->name_);

		$handler=&AmazonSoapHandler::getInstance();
		$amazon=&$handler->get($editform->asin_);
		
		$form=new XoopsThemeForm("AmazonMap","AmazonMap",$_SERVER['SCRIPT_NAME'],"POST");
		
		$ticket=$this->component_->form_->getStructure();
		$form->addElement(new XoopsFormHidden($ticket['__ticket__']['name'],$ticket['__ticket__']['value']));

		foreach($amazon as $key=>$value) {
			// üɽ
			if($key=='Url') {
				$value=@sprintf("<a href='%s' target='_blank'>Amazon Url</a>",$value);
			}
			elseif(strpos($key,"ImageUrl")===0) {
				$value=@sprintf("<img src='%s' alt='%s' />",$value,$value);
			}

			$form->addElement(new XoopsFormLabel($key,nl2br($value)));
		}

       	$formtray = new XoopsFormElementTray("ACTION");
       	$formtray->addElement( new XoopsFormButton ( "", "save", "Confirm", "submit" ) );
       	$backButton = new XoopsFormButton ( "", "back", "Back", "button" );
       	$backButton->setExtra('onclick="javascript:history.go(-1);"');
       	$formtray->addElement($backButton);
        	
       	$form->addElement($formtray);

		$form->display();

	}
}

class AmazonmapInputProcessor extends exTypicalConfirmComponentProcessor
{
	function _processPost($component) {
		global $xoopsDB,$xoopsUser;

		$editform=Session::pop($component->name_);

		$sql=@sprintf("INSERT INTO %s (path,param1,param2,asin,uid) VALUES ( %s,%u,%u,%s,%u)",
			$xoopsDB->prefix("amazonmap_mapping"),
			$xoopsDB->quoteString($editform->path_),
			$editform->param1_,
			$editform->param2_,
			$xoopsDB->quoteString($editform->asin_),
			is_object($xoopsUser) ? $xoopsUser->uid() : 0
			);
			
		return $xoopsDB->query($sql);
	}
}

class AmazonmapDeleteProcessor extends exTypicalConfirmComponentProcessor
{
	function _processPost($component) {
		$db=Database::getInstance();

		if($ret=$component->handler_->delete($component->data_)) {
		
			// åöꥢ
			$sql=@sprintf("DELETE FROM %s WHERE asin='%s'",
				$db->prefix("amazonmap_cache"),
				$component->data_->getVar('asin')
			);
			
			$db->query($sql);
		}
		return ($ret);
	}
}

?>
